<?php
defined('_HZEXEC_') or die();

// Include global scripts
// We're also appending a "last modified" timestamp as a qeurystring.
// This helps in controlling browser caching.
$this->addScript($this->baseurl . '/templates/' . $this->template . '/js/hub.js?v=' . filemtime(__DIR__ . '/js/hub.js'));

// Get the main menu
// We'll use this to determine if we're on the "home" page or not
// and append a classname to the page, if so.
$menu = App::get('menu');

// Get browser info to set some classes
$browser = new \Hubzero\Browser\Detector();

// Build up a list of classes to append to the HTML tag
$cls = array(
	'no-js',
	$browser->name(),
	$browser->name() . $browser->major(),
	$this->direction,
	($menu->getActive() == $menu->getDefault() ? 'home' : '')
);

// Prepend site name to document title
$this->setTitle(Config::get('sitename') . ' - ' . $this->getTitle());
?>
<!DOCTYPE html>
<html dir="<?php echo $this->direction; ?>" lang="<?php echo $this->language; ?>" class="<?php echo implode(' ', $cls); ?>">
	<head>
		<meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=no" />
		<!--[if IE]><meta http-equiv="X-UA-Compatible" content="IE=edge" /><![endif]-->

		<link rel="stylesheet" type="text/css" media="screen" href="<?php echo \Hubzero\Document\Assets::getSystemStylesheet(); ?>" />
		<link rel="stylesheet" type="text/css" media="all" href="<?php echo $this->baseurl; ?>/templates/<?php echo $this->template; ?>/css/index.css?v=<?php echo filemtime(__DIR__ . '/css/index.css'); ?>" />

		<jdoc:include type="head" />

		<!--[if IE 9]>
			<link rel="stylesheet" type="text/css" media="screen" href="<?php echo $this->baseurl; ?>/templates/<?php echo $this->template; ?>/css/browser/ie9.css" />
		<![endif]-->
		<!--[if lt IE 9]>
			<script type="text/javascript" src="<?php echo $this->baseurl; ?>/templates/<?php echo $this->template; ?>/js/html5.js"></script>
			<link rel="stylesheet" type="text/css" media="screen" href="<?php echo $this->baseurl; ?>/templates/<?php echo $this->template; ?>/css/browser/ie8.css" />
		<![endif]-->
	</head>
	<body>
		<jdoc:include type="modules" name="notices" />

		<header id="header">
			<h1>
				<a href="<?php echo Request::root(); ?>" title="<?php echo Config::get('sitename'); ?>">
					<span><?php echo Config::get('sitename'); ?></span>
				</a>
			</h1>

			<ul id="toolbar" class="<?php if (!User::isGuest()) { echo 'loggedin'; } else { echo 'loggedout'; } ?>">
				<?php if (!User::isGuest()) { ?>
					<li id="logout">
						<a href="<?php echo Route::url('index.php?option=com_users&view=logout'); ?>"><span><?php echo Lang::txt('TPL_NEUTRAL_LOGOUT'); ?></span></a>
					</li>
					<li id="myaccount">
						<a href="<?php echo Route::url('index.php?option=com_members&id=' . User::get('id')); ?>"><span><?php echo Lang::txt('TPL_NEUTRAL_MY_ACCOUNT'); ?></span></a>
					</li>
					<li id="usersname">
						<?php echo User::get('name'); ?> (<?php echo User::get('username'); ?>)
					</li>
				<?php } else { ?>
					<li id="login">
						<a href="<?php echo Route::url('index.php?option=com_users&view=logout'); ?>"><?php echo Lang::txt('TPL_NEUTRAL_LOGIN'); ?></a>
					</li>
					<li id="register">
						<a href="<?php echo Route::url('index.php?option=com_register'); ?>"><?php echo Lang::txt('TPL_NEUTRAL_REGISTER'); ?></a>
					</li>
				<?php } ?>
			</ul>

			<jdoc:include type="modules" name="search" />

			<?php if ($this->countModules('helppane')) : ?>
				<p id="tab">
					<a href="<?php echo Route::url('index.php?option=com_support'); ?>" title="<?php echo Lang::txt('TPL_NEUTRAL_NEED_HELP'); ?>">
						<span><?php echo Lang::txt('TPL_NEUTRAL_HELP'); ?></span>
					</a>
				</p>
			<?php endif; ?>
		</header><!-- / #header -->

		<nav id="nav" role="main">
			<jdoc:include type="modules" name="user3" />
		</nav><!-- / #nav -->

		<jdoc:include type="modules" name="helppane" />

		<?php if ($this->countModules('banner or welcome')) : ?>
			<div id="home-splash">
				<div id="splash-wrap">
					<div id="splash">
					<?php if ($this->countModules('banner')) : ?>
						<jdoc:include type="modules" name="banner" />
					<?php endif; ?>
					</div><!-- / #features -->
				</div><!-- / #features-wrap -->
			<?php if ($this->countModules( 'welcome' )) : ?>
				<div id="welcome">
					<jdoc:include type="modules" name="welcome" />
				</div><!-- / #welcome -->
			<?php endif; ?>
			</div><!-- / #home-splash -->
		<?php endif; ?>

		<?php if (!$this->countModules('banner or welcome')) : ?>
			<div id="trail">
				<jdoc:include type="modules" name="breadcrumbs" />
			</div>
		<?php endif; ?>

		<div id="wrap">
			<?php if ($this->getBuffer('message')) : ?>
				<jdoc:include type="message" />
			<?php endif; ?>

			<div id="content" class="<?php echo Request::getCmd('option', 'com_content'); ?>">
				<div class="inner">
					<?php if ($this->countModules('left or right')) : ?>
						<section class="main section">
							<div class="section-inner">
					<?php endif; ?>

					<?php if ($this->countModules('left')) : ?>
							<aside class="aside">
								<jdoc:include type="modules" name="left" />
							</aside><!-- / .aside -->
					<?php endif; ?>
					<?php if ($this->countModules('left or right')) : ?>
							<div class="subject">
					<?php endif; ?>

								<!-- start component output -->
								<jdoc:include type="component" />
								<!-- end component output -->

					<?php if ($this->countModules('left or right')) : ?>
							</div><!-- / .subject -->
					<?php endif; ?>
					<?php if ($this->countModules('right')) : ?>
							<aside class="aside">
								<jdoc:include type="modules" name="right" />
							</aside><!-- / .aside -->
					<?php endif; ?>

					<?php if ($this->countModules('left or right')) : ?>
							</div>
						</section><!-- / .main section -->
					<?php endif; ?>
				</div><!-- / .inner -->
			</div><!-- / #content -->
		</div><!-- / #wrap -->

		<footer id="footer">
			<jdoc:include type="modules" name="footer" />
		</footer><!-- / #footer -->

		<jdoc:include type="modules" name="endpage" />
	</body>
</html>